==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QQuickTransform_shell.h <==
#ifndef QQUICKTRANSFORM_SHELL_H
#define QQUICKTRANSFORM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qmatrix4x4.h>
#include <QtJambi/RegistryAPI>


class QQuickTransform_shell : public QQuickTransform, public QtJambiShellInterface
{
public:
    QQuickTransform_shell(QObject* parent0 = nullptr);
    ~QQuickTransform_shell() override;

    void applyTo(QMatrix4x4* matrix0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTransform_access : public QQuickTransform
{
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_applyTo_QMatrix4x4_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID matrix0) const;
};

#endif // QQUICKTRANSFORM_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QQuickTransform_shell.h <==
#ifndef QQUICKTRANSFORM_SHELL_H
#define QQUICKTRANSFORM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquickitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qmatrix4x4.h>
#include <QtJambi/RegistryAPI>


class QQuickTransform_shell : public QQuickTransform, public QtJambiShellInterface
{
public:
    QQuickTransform_shell(QObject* parent0 = nullptr);
    ~QQuickTransform_shell() override;

    void applyTo(QMatrix4x4* matrix0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTransform_access : public QQuickTransform
{
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_applyTo_QMatrix4x4_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID matrix0) const;
};

#endif // QQUICKTRANSFORM_SHELL_H
